/***************************************************************************

	FILE NAME: DRVR6210.H

	FILE DESCRIPTION: Driver Function Prototypes for DM6210

	This file contains the functions prototypes for all the functions in
	DRVR6210.C.  It must be included with any of the DM6210 example
	programs.

	PROJECT NAME: DM6210 DOS Driver

	DRIVER VERSION: 1.1

	COMPILER: Borland C++ 3.1

	TARGET: Real-Mode DOS

	Copyright 2003 RTD Embedded Technologies

***************************************************************************/

#if !defined(__DRVR6210_H)
#define __DRVR6210_H

typedef unsigned char uchar8;			// 8 bit unsigned integer.
typedef char char8;						// 8 bit signed integer.
typedef unsigned int uint16;			// 16 unsigned integer.
typedef int int16;			// 16 bit signed integer.
typedef float float32;		// 32 bit floating point.

char* TitleString6210(void);


//*************************************************************************
//	InitBoard6210
//
//	This Routine Should allways be called first.
//	This clears the board and varibles the driver uses.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//*************************************************************************
void InitBoard6210(uint16 BaseAddress);


//************************ READ A/D DATA **********************************
//	Read at BA + 0

//*************************************************************************
//	ReadADData6210
//
//	This Routine Reads the A/D Data.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns: 			Unsigned 12-bit A/D data.
//*************************************************************************
uint16  ReadADData6210(uint16 BaseAddress);


//************************ START CONVERSION *******************************
//	Write at BA + 0

//*************************************************************************
//	StartConversion6210
//
//	This routine is used to start A/D conversions.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//*************************************************************************
void StartConversion6210(uint16 BaseAddress);


//************************ RESERVED ************************
//	Read/Write at BA + 1


//************************ BOARD ID ************************
//	Read at BA + 2

//*************************************************************************
//	ReadBoardID6210
//
//	This routine is used to read the board ID register.
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//		Returns the 16-bit ID.
//*************************************************************************
uint16 ReadBoardID6210(uint16 BaseAddress);


//************************ RESERVED ************************
//	Write at BA + 2


//************************ LOAD CHANNEL ******************************
//	Read/Write at BA + 4

//*************************************************************************
//	SetChannel6210
//
//	This routine loads the channel latch.
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//			Channel:		0 - 15
//
//*************************************************************************
void SetChannel6210(uint16 BaseAddress, uint16 Channel);


//************************ IRQ REGISTER ***********************************
//	Read/Write at BA + 5

//*************************************************************************
//	SetIRQ6210
//
//	This routine sets the source and channel for the interrupt.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Source:		0 = A/D End-of-Convert
//  					1 = Timer/Counter Out 0
//						2 = Timer/Counter Out 1
//						3 = Timer/Counter Out 2
//						4 = External Clock 2
//						5 = P0 Latch Status
//						6 = P1 Latch Status
//						7 = Reserved
//
// 	Channel:		0 = disabled
//						1 = IRQ 3
//						2 = IRQ 5
//						3 = IRQ 9
//						4 = IRQ 10
//						5 = IRQ 11
//						6 = IRQ 12
//						7 = IRQ 15
//*************************************************************************
void SetIRQ6210(uint16 BaseAddress, uchar8 Source, uchar8 Channel);


//************************ QUERY ROUTINES *********************************
//	Read at BA + 6

//*************************************************************************
//	ReadStatus6210
//
//	This routine returns the status from the board.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns:				8 bit status word.
//*************************************************************************
uchar8 ReadStatus6210(uint16 BaseAddress);


//*************************************************************************
//	IsADConverting6210
//
//	This routine checks to see if the AD is converting.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns:				1 if AD is converting
//								0 if AD is not converting
//*************************************************************************
uchar8 IsADConverting6210(uint16 BaseAddress);


//*************************************************************************
//	IsIRQ6210
//
//	This routine checks the IRQ status bit.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns:				1 if IRQ has been generated
//								0 if no IRQ
//*************************************************************************
uchar8 IsIRQ6210(uint16 BaseAddress);


//*************************************************************************
//	IsP0Strobe6210
//
//	This routine checks to see if the P0 input strobe has occured.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns:				1 if strobe has occured
//								0 if no strobe
//*************************************************************************
uchar8 IsP0Strobe6210(uint16 BaseAddress);


//*************************************************************************
//	IsP1Strobe6210
//
//	This routine checks to see if the P1 input strobe has occured.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Returns:				1 if strobe has occured
//								0 if no strobe
//*************************************************************************
uchar8 IsP1Strobe6210(uint16 BaseAddress);


//************************ CLEAR ROUTINES *********************************
//	Write at BA + 6

//*************************************************************************
//	ClearIRQ6210
//
//	This routine is used to clear the IRQ circuitry and status bit.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//*************************************************************************
void ClearIRQ6210(uint16 BaseAddress);


//************************ RESERVED *******************************
//	Read/Write at BA + 7


//************************ TIMER COUNTER ROUTINES **************************

//*************************************************************************
//	ClockMode6210
//
//	This routine is used to set the mode of a designated counter
//	in the 8254 programmable interval timer (PIT).
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//		Timer:		0,1,2
//
//		Mode:			0,1,2,3,4,5
//*************************************************************************
void ClockMode6210(uint16 BaseAddress, uchar8 Timer, uchar8 Mode);


//*************************************************************************
//	ClockDivisor6210
//
//	This routine is used to set the divisor of a designated
//	counter on the 8254 programmable interval timer (PIT).  This procedure
//	assumes that the counter has already been set to receive the least
//	significant uchar8 (LSB) of the divisor followed by the most significant
//	uchar8 (MSB).
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//		Timer:		0,1,2
//
//		Divisor:		0 - 65535
//*************************************************************************
void ClockDivisor6210(uint16 BaseAddress, uchar8 Timer, uint16 Divisor);


//*************************************************************************
//	SetUserClock6210
//
//	This routine sets the user timer counters.
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//		Timer:			0, 1, 2
//
//		InputRate:		Input clock to selected timer.
//
//		OutputRate:		Desired output rate from selected timer.
//
// Returns:
//		The actual clock frequency that is programmed.
//*************************************************************************
float32 SetUserClock6210(uint16 BaseAddress, uchar8 Timer, float32 InputRate, float32 OutputRate);


//*************************************************************************
//	ReadTimerCounter6210
//
//	This routine is used to read the contents of the selected timer/counter.
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//
//		Timer:			0,1,2
//
//		Returns the 16-bit count value.
//*************************************************************************
uint16 ReadTimerCounter6210(uint16 BaseAddress, uchar8 Timer);


//*************************************************************************
//	DoneTimer6210
//
//	Initialize the timers for high speed to ensure the immediate load.
//
//	Parameters:
//		BaseAddress:	BaseAddress of board.
//*************************************************************************
void DoneTimer6210(uint16 BaseAddress);


//************************ DIGITAL I/O ROUTINES **************************

//*************************************************************************
//	DIOSetPort0Direction6210
//
//	This routine sets the Port 0 low and Port 0 high direction.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		LDirection:			0 = In
//								1 = Out
//
//		HDirection:			0 = In
//								1 = Out
//*************************************************************************
void DIOSetPort0Direction6210(uint16 BaseAddress, uchar8 LDirection, uchar8 HDirection);


//*************************************************************************
//	DIOSetPort1Direction6210
//
//	This routine sets the Port 1 low and Port 0 high direction.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		LDirection:			0 = In
//								1 = Out
//
//		HDirection:			0 = In
//								1 = Out
//*************************************************************************
void DIOSetPort1Direction6210(uint16 BaseAddress, uchar8 LDirection, uchar8 HDirection);


//*************************************************************************
//	DIOLatchEnable6210
//
//	This routine is used to enable the latched input for Port 0 and Port 1.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		EnableP0:			0 = Disabled
//								1 = Enabled
//
//		EnableP1:			0 = Disabled
//								1 = Enabled
//*************************************************************************
void DIOLatchEnable6210(uint16 BaseAddress, uchar8 EnableP0, uchar8 EnableP1);


//*************************************************************************
//	DIOLatchStrobePolarity6210
//
//	This routine is used to set the latched input strobe polarity for Port 0 and Port 1.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		PolarityP0:			0 = Positive edge
//								1 = Negative edge
//
//		PolarityP1:			0 = Positive edge
//								1 = Negative edge
//*************************************************************************
void DIOLatchStrobePolarity6210(uint16 BaseAddress, uchar8 PolarityP0, uchar8 PolarityP1);


//*************************************************************************
//	DIOSelectStrobe6210
//
//	This routine selects the digital input strobe source.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Strobe:				0 = External Clock 0
//								1 = External Clock 1
//								2 = External Clock 2
//								3 = Reserved
//*************************************************************************
void DIOSelectStrobe6210(uint16 BaseAddress, uchar8 Strobe);


//*************************************************************************
//	DIORead6210
//
//	This routine reads the DIO chip's port.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Port:					0, 1
//*************************************************************************
uchar8 DIORead6210(uint16 BaseAddress, uchar8 Port);


//*************************************************************************
//	DIOWrite6210
//
//	This routine writes the DIO chip's port.
//
//	Parameters:
//		BaseAddress:		BaseAddress of board.
//
//		Port:					0, 1
//
//		Data:					0 - 255
//*************************************************************************
void DIOWrite6210(uint16 BaseAddress, uchar8 Port, uchar8 Data);

#endif  // __DRVR6210_H
