/***************************************************************************

	FILE NAME: SCAN_N.C

	FILE DESCRIPTION: Scanning Multiple Channels Example Program for DM6210

	 Sample program that demonstrates how to perform an analog to digital
	 conversion on multiple channels.

	 While the measurement is running the acquired data on the A/D channels
	 is displayed on the screen, one line with every sample.

	PROJECT NAME: SCAN_N (Part of DM6210 DOS Driver)

	DRIVER VERSION: 1.1

	COMPILER: Borland C++ 3.1

	TARGET: Real-Mode DOS

	Copyright 2003 RTD Embedded Technologies

***************************************************************************/

#include <conio.h>
#include <dos.h>

#include "..\driver\drvr6210.h"

/***************************************************************************
  Defines

  Change these constants to alter the program parameters.
****************************************************************************/

#define BOARD0	 			 0	            // Board 0 array pointer.
#define FIRST_CHAN       0             // First channel to scan.
#define NUM_OF_CHAN      8             // Number of selected channels.
#define ADSLOPE    (4096.0/10.0)       // Number Bits divided by AD Range.


/****************************************************************************
	Global variables
****************************************************************************/

unsigned char BOARD;
unsigned int BASE_ADDRESS[32];

/***************************************************************************
  SetProgramScreen()

  The SetProgramScreen() function initializes the screen.
***************************************************************************/

void SetProgramScreen(void)
{
  int i;

  clrscr();

  // Print header and footer.
  gotoxy( 1, 1); cprintf(TitleString6210());
  gotoxy(50, 1); cprintf("Multi Channel Scan");
  gotoxy( 1,25); cprintf("Press any key to exit. . .");

  // Prepare window to print data and print header above the samples.
  window(1, 3, 80, 23);
  gotoxy( 7, 3);
  for (i = 0; i < NUM_OF_CHAN; i++)
	 cprintf("  CH %d  ", FIRST_CHAN + i + 1);
} //SetProgramScreen


int main(void)
{
  unsigned    i, Channel;
  float       Data;                    // Store acquired data
  int         ADData;


  BASE_ADDRESS[BOARD0] = 768;				// Set base address of board 0.
  BOARD = 0;
  Channel = FIRST_CHAN;

  SetProgramScreen();

	InitBoard6210(BASE_ADDRESS[BOARD]);						// Board initializing.
	SetChannel6210(BASE_ADDRESS[BOARD], Channel);		// Set first channel.
	Channel = Channel + 1;					// Increment to next channel.

	i = 0;                              // Clear sample index.
	gotoxy(7, 5);


  while ( !kbhit() ) {                 // Run until any key pressed.

	StartConversion6210(BASE_ADDRESS[BOARD]);			// Start conversion.
	SetChannel6210(BASE_ADDRESS[BOARD], Channel);	// Set next channel.
	 while (IsADConverting6210(BASE_ADDRESS[BOARD]));	// Wait until data is ready to read.

	 ADData = ReadADData6210(BASE_ADDRESS[BOARD]);     // Read acquired data and convert it
	 Data = (ADData-2048) / ADSLOPE;           			// to voltages.

	 cprintf("%6.3f  ", Data);          // Display 'Data'.

	 Channel = Channel + 1;					// Increment to next channel.
	 if (Channel == FIRST_CHAN + NUM_OF_CHAN){
		Channel = FIRST_CHAN;
	 }

	 if ((++i % NUM_OF_CHAN) == 0){
		gotoxy(7, 5 + i/NUM_OF_CHAN);    // Next line.
	 } // if

	 if (i == (10 * NUM_OF_CHAN)) {
		i = 0;                           // Next screen.
		gotoxy(7, 5);
	 } //if
  } //while
  getch();                             // Get the pressed character.

  window(1,1,80,25);                   // Reset original screen coordinates,
  clrscr();                            // and clear the screen.
  return 0;
} //main
