/***************************************************************************

	FILE NAME: SOFTTRIG.C

	FILE DESCRIPTION: Software Triggering Example Program for DM6210

	 Sample program that demonstrates how to trigger an analog to digital
	 conversion using a software trigger.

	 This simple program samples from the A/D board using software triggering.
	 The acquired data is displayed on the screen.

	PROJECT NAME: SOFTTRIG (Part of DM6210 DOS Driver)

	DRIVER VERSION: 1.1

	COMPILER: Borland C++ 3.1

	TARGET: Real-Mode DOS

	Copyright 2003 RTD Embedded Technologies

***************************************************************************/

#include <conio.h>
#include <dos.h>

#include "..\driver\drvr6210.h"

/***************************************************************************
  Defines

  Change these constants to alter the program parameters.
****************************************************************************/

#define BOARD0	 0				            // Board 0 array pointer.
#define CHANNEL 0                      // A/D channel.
#define ADSLOPE (4096.0/10.0)          // Number Bits divided by AD Range.


/****************************************************************************
	Global variables
****************************************************************************/

unsigned char BOARD;
unsigned int BASE_ADDRESS[32];

/***************************************************************************
  SetProgramScreen()

  The SetProgramScreen() function initializes the screen.
****************************************************************************/

void SetProgramScreen(void)
{
  clrscr();

  // Print header and footer.
  gotoxy(1,1);   cprintf(TitleString6210());
  gotoxy(43, 1); cprintf("Single conversions, software trigger");
  gotoxy(1, 25); cprintf("Press any key to exit. . .");

  window(1, 3, 80, 23);
  gotoxy(25, 8); cprintf("Channel %d :           Volts", CHANNEL + 1);
} //SetProgramScreen

int main(void)
{
  int ADData;
  float Data;                          // Variable to store acquired data.

  BASE_ADDRESS[BOARD0] = 768;				// Set base address of board 0.
  BOARD = 0;

  SetProgramScreen();

  InitBoard6210(BASE_ADDRESS[BOARD]);              // Board initializing.
  SetChannel6210(BASE_ADDRESS[BOARD], CHANNEL); 	// Set channel.

  while ( !kbhit() ) {                 				// Run untill any key is pressed.
	 StartConversion6210(BASE_ADDRESS[BOARD]);      // Perform a Single A/D conversion.

	 while ( IsADConverting6210(BASE_ADDRESS[BOARD]) );	// Wait until data is ready to read.

	 ADData = ReadADData6210(BASE_ADDRESS[BOARD]);  // Read acquired data.
	 Data = (float)((ADData-2048) / ADSLOPE);    				// Convert Data to voltages.
	 gotoxy(37, 8); cprintf("%6.3f", Data);
													// Display 'Data' on the screen.
  } //while
  getch();                             // Get the pressed character.


  window(1,1,80,25);                   // Reset original screen coordinates,
  clrscr();                            // clears the screen.
  return 0;
} //main
