/***************************************************************************

	FILE NAME: TIMERS.C

	FILE DESCRIPTION: User Timer Example Program for DM6210

	 Sample program demonstrating how to program the 8254 programmable
	 interval timers (PITs). Counter 0 is programmed to run at 200 Hz.
	 Counter 1 is used to count these pulses. The result is converted
	 into seconds and printed on the screen.

	PROJECT NAME: TIMERS (Part of DM6210 DOS Driver)

	DRIVER VERSION: 1.1

	COMPILER: Borland C++ 3.1

	TARGET: Real-Mode DOS

	Copyright 2003 RTD Embedded Technologies

***************************************************************************/

#include <conio.h>
#include <dos.h>

#include "..\driver\drvr6210.h"


/***************************************************************************
  Defines

  Change these constants to alter the program parameters.
****************************************************************************/
#define BOARD0	 0				            // Board 0 array pointer.


/****************************************************************************
	Global variables
****************************************************************************/

unsigned char BOARD;
unsigned int BASE_ADDRESS[32];

/***************************************************************************
  SetProgramScreen()

  The SetProgramScreen() function initializes the screen.
****************************************************************************/

void SetProgramScreen(void)
{
  clrscr();

  // Print header and footer.
  gotoxy( 1, 1); cprintf(TitleString6210());
  gotoxy(50, 1); cprintf("Timer Example");
  gotoxy( 1,25); cprintf("Press any key to exit. . .");

  window(1, 3, 80, 23);
  gotoxy(25, 8); cprintf("Elapsed time:     0.0  seconds");
} //SetProgramScreen


int main(void)
{
  BASE_ADDRESS[BOARD0] = 768;				// Set base address of board 0.
  BOARD = 0;

  clrscr();
  SetProgramScreen();

  InitBoard6210(BASE_ADDRESS[BOARD]);                // Board initializing.

  ClockMode6210(BASE_ADDRESS[BOARD], 0,2);           // Set Clock 0 to mode 2
  ClockMode6210(BASE_ADDRESS[BOARD], 1,0);           // Set Clock 1 to mode 0
  ClockDivisor6210(BASE_ADDRESS[BOARD], 0,40000);    // Set Clock 0 Divider to 40,000
  ClockDivisor6210(BASE_ADDRESS[BOARD], 1,0xFFFF);   // Set Clock 1 starting value

  while (!kbhit()) {                   // Run until any key pressed.

	gotoxy(40, 8);
	cprintf("%6.1f",  (float)(65535 - ReadTimerCounter6210(BASE_ADDRESS[BOARD], 1)) / 200.0 );
  } //while

  DoneTimer6210(BASE_ADDRESS[BOARD]);  // Shut down user timer.

  window(1,1,80,25);                   // Reset original screen coordinates,
  clrscr();                            // and clear the screen.
  return 0;
} //main
